# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: weatherData.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'weatherData.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11weatherData.proto\x12\x0fWeatherSettings\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa7\x05\n\x0eWeatherSetting\x12\x30\n\x0bweatherRows\x18\x01 \x03(\x0b\x32\x1b.WeatherSettings.WeatherRow\x12\x10\n\x08Latitude\x18\x02 \x01(\x02\x12\x11\n\tLongitude\x18\x03 \x01(\x02\x12\x18\n\x10\x45levation_Metres\x18\x04 \x01(\x02\x12-\n\tStartDate\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x45ndDate\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x0fObservationType\x18\x07 \x01(\x0e\x32$.WeatherSettings.ObservationTypeEnum\x12\x33\n\nDataSource\x18\x08 \x01(\x0e\x32\x1f.WeatherSettings.DataSourceEnum\x12\x1e\n\x16HorizonShadowsIncluded\x18\t \x01(\x08\x12\x13\n\x0bRadiationDB\x18\n \x01(\t\x12\x0f\n\x07MeteoDB\x18\x0b \x01(\t\x12\x11\n\tHorizonDB\x18\x0c \x01(\t\x12G\n\x1fLocalStandardTimeOffset_Minutes\x18\r \x01(\x0b\x32\x1e.WeatherSettings.NullableInt32\x12\x1a\n\x12LocalTimeZone_IANA\x18\x0e \x01(\t\x12\x41\n\x11ObservationPeriod\x18\x0f \x01(\x0e\x32&.WeatherSettings.ObservationPeriodEnum\x12\x15\n\rversionNumber\x18\x10 \x01(\x05\x12<\n\x19ObservationPeriodDuration\x18\x11 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xff\x08\n\nWeatherRow\x12\x37\n\x13ObservationTime_UTC\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12W\n/GlobalHorizontalIrradiance_WattsPerMetreSquared\x18\x02 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12S\n+DirectNormalIrradiance_WattsPerMetreSquared\x18\x03 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12X\n0DiffuseHorizontalIrradiance_WattsPerMetreSquared\x18\x04 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12\x42\n\x1aSurfaceAirPressure_Pascals\x18\x05 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12Q\n)DryBulbTemperature_DegreesCeliusAt2Metres\x18\x06 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12N\n&WindVelocity_MetresPerSecondAt10Metres\x18\x07 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12Y\n1WindDirection_DegreesClockwiseFromNorthAt10Metres\x18\x08 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12@\n\x18RelativeHumidity_Percent\x18\t \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12V\n.SurfaceInfraredIrradiance_WattsPerMeterSquared\x18\n \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12\x41\n\x19PrecipitableWaterVapourCM\x18\x0b \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12\x33\n\x0bSolarZenith\x18\x0c \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12\x34\n\x0cSolarAzimuth\x18\r \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12\x33\n\x0bOzone_AtmCm\x18\x0e \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12\x31\n\tTurbidity\x18\x0f \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\x12>\n\x16\x46\x61rFieldAlbedo_Percent\x18\x10 \x01(\x0b\x32\x1e.WeatherSettings.NullableFloat\"S\n\rNullableFloat\x12*\n\x04null\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x0e\n\x04\x64\x61ta\x18\x02 \x01(\x02H\x00\x42\x06\n\x04kind\"S\n\rNullableInt32\x12*\n\x04null\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x0e\n\x04\x64\x61ta\x18\x02 \x01(\x05H\x00\x42\x06\n\x04kind*\'\n\x0e\x44\x61taSourceEnum\x12\n\n\x06UPLOAD\x10\x00\x12\t\n\x05PVGIS\x10\x01*,\n\x13ObservationTypeEnum\x12\x07\n\x03TMY\x10\x00\x12\x0c\n\x08OBSERVED\x10\x01*\x83\x01\n\x15ObservationPeriodEnum\x12%\n!Deprecated_ZenithAzimuthSpecified\x10\x00\x12\x11\n\rInstantaneous\x10\x01\x12\r\n\tEndOfHour\x10\x02\x12\x0f\n\x0bStartOfHour\x10\x03\x12\x10\n\x0cMiddleOfHour\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'weatherData_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DATASOURCEENUM']._serialized_start=2139
  _globals['_DATASOURCEENUM']._serialized_end=2178
  _globals['_OBSERVATIONTYPEENUM']._serialized_start=2180
  _globals['_OBSERVATIONTYPEENUM']._serialized_end=2224
  _globals['_OBSERVATIONPERIODENUM']._serialized_start=2227
  _globals['_OBSERVATIONPERIODENUM']._serialized_end=2358
  _globals['_WEATHERSETTING']._serialized_start=134
  _globals['_WEATHERSETTING']._serialized_end=813
  _globals['_WEATHERROW']._serialized_start=816
  _globals['_WEATHERROW']._serialized_end=1967
  _globals['_NULLABLEFLOAT']._serialized_start=1969
  _globals['_NULLABLEFLOAT']._serialized_end=2052
  _globals['_NULLABLEINT32']._serialized_start=2054
  _globals['_NULLABLEINT32']._serialized_end=2137
# @@protoc_insertion_point(module_scope)
