# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: uncertainty.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'uncertainty.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import uncertaintyMessages_pb2 as uncertaintyMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11uncertainty.proto\x12\x11grpc.SunSolve.API\x1a\x19uncertaintyMessages.proto2u\n\x0bUncertainty\x12\x66\n\x13UncertaintyAnalysis\x12%.grpc.SunSolve.API.UncertaintyRequest\x1a&.grpc.SunSolve.API.UncertaintyResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'uncertainty_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UNCERTAINTY']._serialized_start=67
  _globals['_UNCERTAINTY']._serialized_end=184
# @@protoc_insertion_point(module_scope)
