# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: uncertaintyMessages.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'uncertaintyMessages.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19uncertaintyMessages.proto\x12\x11grpc.SunSolve.API\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfa\x01\n\x13UncertaintyResponse\x12\x13\n\x0bpctComplete\x18\x01 \x01(\x02\x12J\n\x10SimulationResult\x18\x02 \x01(\x0b\x32..grpc.SunSolve.API.UncertaintySimulationResultH\x00\x12\x38\n\x07Summary\x18\x03 \x01(\x0b\x32%.grpc.SunSolve.API.UncertaintySummaryH\x00\x12>\n\nInputsUsed\x18\x04 \x01(\x0b\x32(.grpc.SunSolve.API.UncertaintyUsedInputsH\x00\x42\x08\n\x06Result\"\xab\x01\n\x1bUncertaintySimulationResult\x12\x17\n\x0fSimulationIndex\x18\x01 \x01(\x02\x12\x12\n\nYearNumber\x18\x02 \x01(\x02\x12\x14\n\x0cTotalDCYield\x18\x03 \x01(\x01\x12\x14\n\x0cTotalACYield\x18\x04 \x01(\x01\x12\x1e\n\x16YearlyAvailableYieldAC\x18\x05 \x01(\x01\x12\x13\n\x0b\x44\x65gradation\x18\x06 \x01(\x01\"\xb9\x01\n\x12UncertaintySummary\x12/\n\x0cYearlyPValue\x18\x01 \x03(\x0b\x32\x19.grpc.SunSolve.API.PValue\x12\x35\n\x0fYearlyHistogram\x18\x02 \x03(\x0b\x32\x1c.grpc.SunSolve.API.Histogram\x12;\n\x12YearlyP50Deviation\x18\x03 \x03(\x0b\x32\x1f.grpc.SunSolve.API.P50Deviation\"\xda\x03\n\x15UncertaintyUsedInputs\x12-\n\x06Module\x18\x01 \x01(\x0b\x32\x1d.grpc.SunSolve.API.ModuleInfo\x12-\n\x06System\x18\x02 \x01(\x0b\x32\x1d.grpc.SunSolve.API.SystemInfo\x12\x39\n\nElectrical\x18\x03 \x01(\x0b\x32%.grpc.SunSolve.API.ElectricalSettings\x12\x33\n\x07Optical\x18\x04 \x01(\x0b\x32\".grpc.SunSolve.API.OpticalSettings\x12\x33\n\x07Thermal\x18\x05 \x01(\x0b\x32\".grpc.SunSolve.API.ThermalSettings\x12\x39\n\tOperation\x18\x06 \x01(\x0b\x32&.grpc.SunSolve.API.OperationalSettings\x12J\n\x11SimulationOptions\x18\x07 \x01(\x0b\x32/.grpc.SunSolve.API.UncertaintySimulationOptions\x12\x37\n\rResultOptions\x18\x08 \x01(\x0b\x32 .grpc.SunSolve.API.ResultOptions\"u\n\x06PValue\x12\x0c\n\x04Year\x18\x01 \x01(\x05\x12\t\n\x01P\x18\x02 \x01(\x05\x12\x12\n\x05Value\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x14\n\x0cP50Deviation\x18\x04 \x01(\x01\x12\x13\n\x06\x43onf95\x18\x05 \x01(\x01H\x01\x88\x01\x01\x42\x08\n\x06_ValueB\t\n\x07_Conf95\"\'\n\tHistogram\x12\x0c\n\x04Year\x18\x01 \x01(\x05\x12\x0c\n\x04\x62ins\x18\x02 \x03(\x05\"+\n\x0cP50Deviation\x12\x0c\n\x04Year\x18\x01 \x01(\x05\x12\r\n\x05Value\x18\x02 \x01(\x01\"\xc3\x06\n\x12UncertaintyRequest\x12;\n\nTMYDataSet\x18\x01 \x01(\x0b\x32%.grpc.SunSolve.API.TMYTimeStepDataSetH\x00\x12G\n\x13\x41\x63tualYearlyDataSet\x18\x02 \x01(\x0b\x32(.grpc.SunSolve.API.ActualTimeStepDataSetH\x00\x12\x32\n\x06Module\x18\x03 \x01(\x0b\x32\x1d.grpc.SunSolve.API.ModuleInfoH\x01\x88\x01\x01\x12\x32\n\x06System\x18\x04 \x01(\x0b\x32\x1d.grpc.SunSolve.API.SystemInfoH\x02\x88\x01\x01\x12>\n\nElectrical\x18\x05 \x01(\x0b\x32%.grpc.SunSolve.API.ElectricalSettingsH\x03\x88\x01\x01\x12\x38\n\x07Optical\x18\x06 \x01(\x0b\x32\".grpc.SunSolve.API.OpticalSettingsH\x04\x88\x01\x01\x12\x38\n\x07Thermal\x18\x07 \x01(\x0b\x32\".grpc.SunSolve.API.ThermalSettingsH\x05\x88\x01\x01\x12>\n\tOperation\x18\x08 \x01(\x0b\x32&.grpc.SunSolve.API.OperationalSettingsH\x06\x88\x01\x01\x12O\n\x11SimulationOptions\x18\t \x01(\x0b\x32/.grpc.SunSolve.API.UncertaintySimulationOptionsH\x07\x88\x01\x01\x12<\n\rResultOptions\x18\n \x01(\x0b\x32 .grpc.SunSolve.API.ResultOptionsH\x08\x88\x01\x01\x12\x36\n\rDistributions\x18\x0b \x03(\x0b\x32\x1f.grpc.SunSolve.API.DistributionB\x11\n\x0fTimeStepDataSetB\t\n\x07_ModuleB\t\n\x07_SystemB\r\n\x0b_ElectricalB\n\n\x08_OpticalB\n\n\x08_ThermalB\x0c\n\n_OperationB\x14\n\x12_SimulationOptionsB\x10\n\x0e_ResultOptions\"Q\n\x12TMYTimeStepDataSet\x12;\n\x12TimeStepDataPoints\x18\x01 \x03(\x0b\x32\x1f.grpc.SunSolve.API.TimeStepData\"a\n\x15\x41\x63tualTimeStepDataSet\x12H\n\x12TimeStepDataPoints\x18\x01 \x03(\x0b\x32,.grpc.SunSolve.API.ActualTimeStepDataForYear\"k\n\x19\x41\x63tualTimeStepDataForYear\x12\x11\n\tYearIndex\x18\x01 \x01(\x05\x12;\n\x12TimeStepDataPoints\x18\x02 \x03(\x0b\x32\x1f.grpc.SunSolve.API.TimeStepData\"\x89\x04\n\x0cTimeStepData\x12\x32\n\x0e\x45ndOfPeriodUTC\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x08SolarPos\x18\x02 \x01(\x0b\x32/.grpc.SunSolve.API.YieldTimeSeriesSolarPosition\x12:\n\x07Weather\x18\x03 \x01(\x0b\x32).grpc.SunSolve.API.YieldTimeSeriesWeather\x12\x1f\n\x12TiltAngleInDegrees\x18\x04 \x01(\x01H\x00\x88\x01\x01\x12\x13\n\x06\x41lbedo\x18\x05 \x01(\x01H\x01\x88\x01\x01\x12\x1d\n\x10SoilingFrontRate\x18\x06 \x01(\x01H\x02\x88\x01\x01\x12\x1c\n\x0fSoilingRearRate\x18\x07 \x01(\x01H\x03\x88\x01\x01\x12#\n\x16RearTransmissionFactor\x18\x08 \x01(\x01H\x04\x88\x01\x01\x12(\n\x1bRearStructuralShadingFactor\x18\t \x01(\x01H\x05\x88\x01\x01\x42\x15\n\x13_TiltAngleInDegreesB\t\n\x07_AlbedoB\x13\n\x11_SoilingFrontRateB\x12\n\x10_SoilingRearRateB\x19\n\x17_RearTransmissionFactorB\x1e\n\x1c_RearStructuralShadingFactor\"\xc8\x02\n\nModuleInfo\x12\x16\n\tLengthInM\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08WidthInM\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x1f\n\x12\x43\x65llToCellMismatch\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12.\n!ModulePowerTemperatureCoefficient\x18\x04 \x01(\x01H\x03\x88\x01\x01\x12 \n\x13PowerRatingAtSTCInW\x18\x05 \x01(\x01H\x04\x88\x01\x01\x12\x18\n\x0b\x42ifaciality\x18\x06 \x01(\x01H\x05\x88\x01\x01\x42\x0c\n\n_LengthInMB\x0b\n\t_WidthInMB\x15\n\x13_CellToCellMismatchB$\n\"_ModulePowerTemperatureCoefficientB\x16\n\x14_PowerRatingAtSTCInWB\x0e\n\x0c_Bifaciality\"\x97\x04\n\nSystemInfo\x12\x1e\n\x11NumberOfInverters\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1f\n\x12StringsPerInverter\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1d\n\x10ModulesPerString\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x18\n\x0bRowPitchInM\x18\x04 \x01(\x01H\x03\x88\x01\x01\x12#\n\x16ModuleAzimuthInDegrees\x18\x05 \x01(\x01H\x04\x88\x01\x01\x12(\n\x1b\x46\x61llbackModuleTiltInDegrees\x18\x06 \x01(\x01H\x05\x88\x01\x01\x12<\n\x0eModuleTracking\x18\x07 \x01(\x0e\x32\x1f.grpc.SunSolve.API.TrackingTypeH\x06\x88\x01\x01\x12\x1f\n\x12TiltLimitInDegrees\x18\x08 \x01(\x01H\x07\x88\x01\x01\x12\x19\n\x0cModuleHeight\x18\t \x01(\x01H\x08\x88\x01\x01\x42\x14\n\x12_NumberOfInvertersB\x15\n\x13_StringsPerInverterB\x13\n\x11_ModulesPerStringB\x0e\n\x0c_RowPitchInMB\x19\n\x17_ModuleAzimuthInDegreesB\x1e\n\x1c_FallbackModuleTiltInDegreesB\x11\n\x0f_ModuleTrackingB\x15\n\x13_TiltLimitInDegreesB\x0f\n\r_ModuleHeight\"\xd3\x05\n\x0fOpticalSettings\x12 \n\x13\x42\x65\x61mMultiplierFront\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12%\n\x18IsotropicMultiplierFront\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x1f\n\x12\x42\x65\x61mMultiplierRear\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12$\n\x17IsotropicMultiplierRear\x18\x04 \x01(\x01H\x03\x88\x01\x01\x12\x1b\n\x0e\x46\x61llbackAlbedo\x18\x05 \x01(\x01H\x04\x88\x01\x01\x12!\n\x14\x46\x61llbackSoilingFront\x18\x06 \x01(\x01H\x05\x88\x01\x01\x12 \n\x13\x46\x61llbackSoilingRear\x18\x07 \x01(\x01H\x06\x88\x01\x01\x12\'\n\x1a\x46\x61llbackSpectralCorrection\x18\x08 \x01(\x01H\x07\x88\x01\x01\x12\x1c\n\x0f\x45xtraIrradiance\x18\t \x01(\x01H\x08\x88\x01\x01\x12+\n\x1e\x46\x61llbackRearTransmissionFactor\x18\n \x01(\x01H\t\x88\x01\x01\x12\x30\n#FallbackRearStructuralShadingFactor\x18\x0b \x01(\x01H\n\x88\x01\x01\x42\x16\n\x14_BeamMultiplierFrontB\x1b\n\x19_IsotropicMultiplierFrontB\x15\n\x13_BeamMultiplierRearB\x1a\n\x18_IsotropicMultiplierRearB\x11\n\x0f_FallbackAlbedoB\x17\n\x15_FallbackSoilingFrontB\x16\n\x14_FallbackSoilingRearB\x1d\n\x1b_FallbackSpectralCorrectionB\x12\n\x10_ExtraIrradianceB!\n\x1f_FallbackRearTransmissionFactorB&\n$_FallbackRearStructuralShadingFactor\"\xf0\x03\n\x12\x45lectricalSettings\x12\x1f\n\x12InverterEfficiency\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\'\n\x1aInverterToInverterMismatch\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12#\n\x16StringToStringMismatch\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12#\n\x16ModuleToModuleMismatch\x18\x04 \x01(\x01H\x03\x88\x01\x01\x12\x1f\n\x12InverterWiringLoss\x18\x05 \x01(\x01H\x04\x88\x01\x01\x12\x1d\n\x10StringWiringLoss\x18\x06 \x01(\x01H\x05\x88\x01\x01\x12!\n\x14MaxPowerTrackingLoss\x18\x07 \x01(\x01H\x06\x88\x01\x01\x12\x1d\n\x10InverterClipping\x18\x08 \x01(\x01H\x07\x88\x01\x01\x42\x15\n\x13_InverterEfficiencyB\x1d\n\x1b_InverterToInverterMismatchB\x19\n\x17_StringToStringMismatchB\x19\n\x17_ModuleToModuleMismatchB\x15\n\x13_InverterWiringLossB\x13\n\x11_StringWiringLossB\x17\n\x15_MaxPowerTrackingLossB\x13\n\x11_InverterClipping\"_\n\x0fThermalSettings\x12\x0f\n\x02Uc\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x0f\n\x02Uv\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x12\n\x05\x41lpha\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\x05\n\x03_UcB\x05\n\x03_UvB\x08\n\x06_Alpha\"\xaf\x02\n\x13OperationalSettings\x12\"\n\x15\x41nnualDegradationRate\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x44\x43Health\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x19\n\x0c\x41vailability\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x18\n\x0b\x43urtailment\x18\x04 \x01(\x01H\x03\x88\x01\x01\x12\x1a\n\rYieldModifier\x18\x05 \x01(\x01H\x04\x88\x01\x01\x12\x1d\n\x10UndulatingGround\x18\x06 \x01(\x01H\x05\x88\x01\x01\x42\x18\n\x16_AnnualDegradationRateB\x0b\n\t_DCHealthB\x0f\n\r_AvailabilityB\x0e\n\x0c_CurtailmentB\x10\n\x0e_YieldModifierB\x13\n\x11_UndulatingGround\"\x86\x01\n\x1cUncertaintySimulationOptions\x12 \n\x13NumberOfSimulations\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1a\n\rNumberOfYears\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x16\n\x14_NumberOfSimulationsB\x10\n\x0e_NumberOfYears\"\x9c\x01\n\rResultOptions\x12\x13\n\x06\x42inMin\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x15\n\x08\x42inDelta\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x0f\n\x07PValues\x18\x03 \x03(\x05\x12\x1f\n\x12IncludeYieldResult\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_BinMinB\x0b\n\t_BinDeltaB\x15\n\x13_IncludeYieldResult\"\xf2\x02\n\x0c\x44istribution\x12\x33\n\x05Input\x18\x01 \x01(\x0e\x32$.grpc.SunSolve.API.DistributionInput\x12J\n\x14SimToSimDistribution\x18\x02 \x01(\x0b\x32\'.grpc.SunSolve.API.DistributionFunctionH\x00\x88\x01\x01\x12H\n\x12YrToYrDistribution\x18\x03 \x01(\x0b\x32\'.grpc.SunSolve.API.DistributionFunctionH\x01\x88\x01\x01\x12L\n\x16StepToStepDistribution\x18\x04 \x01(\x0b\x32\'.grpc.SunSolve.API.DistributionFunctionH\x02\x88\x01\x01\x42\x17\n\x15_SimToSimDistributionB\x15\n\x13_YrToYrDistributionB\x19\n\x17_StepToStepDistribution\"\x92\x03\n\x14\x44istributionFunction\x12\x31\n\x04Type\x18\x01 \x01(\x0e\x32#.grpc.SunSolve.API.DistributionType\x12;\n\x08\x43onstant\x18\x02 \x01(\x0b\x32\'.grpc.SunSolve.API.ConstantDistributionH\x00\x12;\n\x08Gaussian\x18\x03 \x01(\x0b\x32\'.grpc.SunSolve.API.GaussianDistributionH\x00\x12\x39\n\x07Weibull\x18\x04 \x01(\x0b\x32&.grpc.SunSolve.API.WeibullDistributionH\x00\x12G\n\x0eSkewedGaussian\x18\x05 \x01(\x0b\x32-.grpc.SunSolve.API.SkewedGaussianDistributionH\x00\x12=\n\tArbitrary\x18\x06 \x01(\x0b\x32(.grpc.SunSolve.API.ArbitraryDistributionH\x00\x42\n\n\x08\x46unction\"%\n\x14\x43onstantDistribution\x12\r\n\x05Value\x18\x01 \x01(\x01\"\xf1\x01\n\x14GaussianDistribution\x12\n\n\x02x0\x18\x01 \x01(\x01\x12\r\n\x05sigma\x18\x02 \x01(\x01\x12\x11\n\x04\x66max\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12+\n\x1enumPointsInProbabilityFunction\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0bxLowerLimit\x18\x05 \x01(\x01H\x02\x88\x01\x01\x12\x18\n\x0bxUpperLimit\x18\x06 \x01(\x01H\x03\x88\x01\x01\x42\x07\n\x05_fmaxB!\n\x1f_numPointsInProbabilityFunctionB\x0e\n\x0c_xLowerLimitB\x0e\n\x0c_xUpperLimit\"\xb4\x01\n\x1aSkewedGaussianDistribution\x12\r\n\x05\x61lpha\x18\x01 \x01(\x01\x12\x0c\n\x04zeta\x18\x02 \x01(\x01\x12\r\n\x05omega\x18\x03 \x01(\x01\x12\x11\n\x04\x66max\x18\x04 \x01(\x01H\x00\x88\x01\x01\x12+\n\x1enumPointsInProbabilityFunction\x18\x05 \x01(\x05H\x01\x88\x01\x01\x42\x07\n\x05_fmaxB!\n\x1f_numPointsInProbabilityFunction\"v\n\x13WeibullDistribution\x12\n\n\x02x0\x18\x01 \x01(\x01\x12\x0e\n\x06lambda\x18\x02 \x01(\x01\x12\t\n\x01k\x18\x03 \x01(\x01\x12 \n\x13hasPositivePolarity\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_hasPositivePolarity\"-\n\x15\x41rbitraryDistribution\x12\t\n\x01x\x18\x01 \x03(\x01\x12\t\n\x01y\x18\x02 \x03(\x01\"g\n\x1cYieldTimeSeriesSolarPosition\x12\x15\n\rZenithDegrees\x18\x01 \x01(\x02\x12\x16\n\x0e\x41zimuthDegrees\x18\x02 \x01(\x02\x12\x18\n\x10\x45levationDegrees\x18\x03 \x01(\x02\"\x94\x01\n\x16YieldTimeSeriesWeather\x12\x0b\n\x03GHI\x18\x01 \x01(\x02\x12\x0b\n\x03\x44HI\x18\x02 \x01(\x02\x12\x0b\n\x03\x44NI\x18\x03 \x01(\x02\x12\x17\n\x0f\x44iffuseFraction\x18\x04 \x01(\x02\x12\x13\n\x0b\x41mbientTemp\x18\x05 \x01(\x02\x12\n\n\x02WS\x18\x06 \x01(\x02\x12\n\n\x02WD\x18\x07 \x01(\x02\x12\r\n\x05\x43loud\x18\x08 \x01(\x02*#\n\x0cTrackingType\x12\n\n\x06NotSet\x10\x00\x12\x07\n\x03SAT\x10\x01*\xd3\x04\n\x11\x44istributionInput\x12\x07\n\x03GHI\x10\x00\x12\x13\n\x0f\x44iffuseFraction\x10\x01\x12\r\n\tWindSpeed\x10\x02\x12\x0f\n\x0bTemperature\x10\x03\x12\x0f\n\x0bModulePower\x10\x04\x12\x16\n\x12SpectralCorrection\x10\x05\x12\x10\n\x0cSoilingFront\x10\x06\x12\x0f\n\x0bSoilingRear\x10\x07\x12\x06\n\x02Uc\x10\x08\x12\x06\n\x02Uv\x10\t\x12\t\n\x05\x41lpha\x10\n\x12\x19\n\x15\x41nnualDegradationRate\x10\x0b\x12\x10\n\x0c\x41vailability\x10\x0c\x12\x11\n\rYieldModifier\x10\r\x12\x17\n\x13\x43ircumsolarFraction\x10\x0e\x12\x14\n\x10UndulatingGround\x10\x0f\x12\x13\n\x0f\x45xtraIrradiance\x10\x10\x12\x0f\n\x0b\x43urtailment\x10\x11\x12\x0c\n\x08\x44\x43Health\x10\x12\x12\x1e\n\x1aInverterToInverterMismatch\x10\x13\x12\x1a\n\x16StringToStringMismatch\x10\x14\x12\x1a\n\x16ModuleToModuleMismatch\x10\x15\x12\x16\n\x12\x43\x65llToCellMismatch\x10\x16\x12\x16\n\x12InverterEfficiency\x10\x17\x12%\n!ModulePowerTemperatureCoefficient\x10\x18\x12\n\n\x06\x41lbedo\x10\x19\x12\x1f\n\x1bRearStructuralShadingFactor\x10\x1a\x12\x1a\n\x16RearTransmissionFactor\x10\x1b*^\n\x10\x44istributionType\x12\x0c\n\x08\x43onstant\x10\x00\x12\x0c\n\x08Gaussian\x10\x01\x12\x0b\n\x07Weibull\x10\x02\x12\x12\n\x0eSkewedGaussian\x10\x03\x12\r\n\tArbitrary\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'uncertaintyMessages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRACKINGTYPE']._serialized_start=7491
  _globals['_TRACKINGTYPE']._serialized_end=7526
  _globals['_DISTRIBUTIONINPUT']._serialized_start=7529
  _globals['_DISTRIBUTIONINPUT']._serialized_end=8124
  _globals['_DISTRIBUTIONTYPE']._serialized_start=8126
  _globals['_DISTRIBUTIONTYPE']._serialized_end=8220
  _globals['_UNCERTAINTYRESPONSE']._serialized_start=82
  _globals['_UNCERTAINTYRESPONSE']._serialized_end=332
  _globals['_UNCERTAINTYSIMULATIONRESULT']._serialized_start=335
  _globals['_UNCERTAINTYSIMULATIONRESULT']._serialized_end=506
  _globals['_UNCERTAINTYSUMMARY']._serialized_start=509
  _globals['_UNCERTAINTYSUMMARY']._serialized_end=694
  _globals['_UNCERTAINTYUSEDINPUTS']._serialized_start=697
  _globals['_UNCERTAINTYUSEDINPUTS']._serialized_end=1171
  _globals['_PVALUE']._serialized_start=1173
  _globals['_PVALUE']._serialized_end=1290
  _globals['_HISTOGRAM']._serialized_start=1292
  _globals['_HISTOGRAM']._serialized_end=1331
  _globals['_P50DEVIATION']._serialized_start=1333
  _globals['_P50DEVIATION']._serialized_end=1376
  _globals['_UNCERTAINTYREQUEST']._serialized_start=1379
  _globals['_UNCERTAINTYREQUEST']._serialized_end=2214
  _globals['_TMYTIMESTEPDATASET']._serialized_start=2216
  _globals['_TMYTIMESTEPDATASET']._serialized_end=2297
  _globals['_ACTUALTIMESTEPDATASET']._serialized_start=2299
  _globals['_ACTUALTIMESTEPDATASET']._serialized_end=2396
  _globals['_ACTUALTIMESTEPDATAFORYEAR']._serialized_start=2398
  _globals['_ACTUALTIMESTEPDATAFORYEAR']._serialized_end=2505
  _globals['_TIMESTEPDATA']._serialized_start=2508
  _globals['_TIMESTEPDATA']._serialized_end=3029
  _globals['_MODULEINFO']._serialized_start=3032
  _globals['_MODULEINFO']._serialized_end=3360
  _globals['_SYSTEMINFO']._serialized_start=3363
  _globals['_SYSTEMINFO']._serialized_end=3898
  _globals['_OPTICALSETTINGS']._serialized_start=3901
  _globals['_OPTICALSETTINGS']._serialized_end=4624
  _globals['_ELECTRICALSETTINGS']._serialized_start=4627
  _globals['_ELECTRICALSETTINGS']._serialized_end=5123
  _globals['_THERMALSETTINGS']._serialized_start=5125
  _globals['_THERMALSETTINGS']._serialized_end=5220
  _globals['_OPERATIONALSETTINGS']._serialized_start=5223
  _globals['_OPERATIONALSETTINGS']._serialized_end=5526
  _globals['_UNCERTAINTYSIMULATIONOPTIONS']._serialized_start=5529
  _globals['_UNCERTAINTYSIMULATIONOPTIONS']._serialized_end=5663
  _globals['_RESULTOPTIONS']._serialized_start=5666
  _globals['_RESULTOPTIONS']._serialized_end=5822
  _globals['_DISTRIBUTION']._serialized_start=5825
  _globals['_DISTRIBUTION']._serialized_end=6195
  _globals['_DISTRIBUTIONFUNCTION']._serialized_start=6198
  _globals['_DISTRIBUTIONFUNCTION']._serialized_end=6600
  _globals['_CONSTANTDISTRIBUTION']._serialized_start=6602
  _globals['_CONSTANTDISTRIBUTION']._serialized_end=6639
  _globals['_GAUSSIANDISTRIBUTION']._serialized_start=6642
  _globals['_GAUSSIANDISTRIBUTION']._serialized_end=6883
  _globals['_SKEWEDGAUSSIANDISTRIBUTION']._serialized_start=6886
  _globals['_SKEWEDGAUSSIANDISTRIBUTION']._serialized_end=7066
  _globals['_WEIBULLDISTRIBUTION']._serialized_start=7068
  _globals['_WEIBULLDISTRIBUTION']._serialized_end=7186
  _globals['_ARBITRARYDISTRIBUTION']._serialized_start=7188
  _globals['_ARBITRARYDISTRIBUTION']._serialized_end=7233
  _globals['_YIELDTIMESERIESSOLARPOSITION']._serialized_start=7235
  _globals['_YIELDTIMESERIESSOLARPOSITION']._serialized_end=7338
  _globals['_YIELDTIMESERIESWEATHER']._serialized_start=7341
  _globals['_YIELDTIMESERIESWEATHER']._serialized_end=7489
# @@protoc_insertion_point(module_scope)
